AutoScalingGroupConfiguration class

Describes the configuration of an Auto Scaling group.

Constructors

AutoScalingGroupConfiguration({int? desiredCapacity, String? instanceType, int? maxSize, int? minSize})
AutoScalingGroupConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

desiredCapacity → int?
The desired capacity, or number of instances, for the Auto Scaling group.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceType → String?
The instance type for the Auto Scaling group.
final
maxSize → int?
The maximum size, or maximum number of instances, for the Auto Scaling group.
final
minSize → int?
The minimum size, or minimum number of instances, for the Auto Scaling group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited