GetEC2InstanceRecommendationsResponse class

Properties

errors → List<GetRecommendationError>?
An array of objects that describe errors of the request.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceRecommendations → List<InstanceRecommendation>?
An array of objects that describe instance recommendations.
final
nextToken → String?
The token to use to advance to the next page of instance recommendations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited