GetEnrollmentStatusResponse class

Constructors

GetEnrollmentStatusResponse({bool? memberAccountsEnrolled, Status? status, String? statusReason})
GetEnrollmentStatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
memberAccountsEnrolled → bool?
Confirms the enrollment status of member accounts within the organization, if the account is a management account of an organization.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status?
The enrollment status of the account.
final
statusReason → String?
The reason for the enrollment status of the account.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited