InstanceRecommendation class

Describes an Amazon EC2 instance recommendation.

Constructors

InstanceRecommendation({String? accountId, String? currentInstanceType, Finding? finding, String? instanceArn, String? instanceName, DateTime? lastRefreshTimestamp, double? lookBackPeriodInDays, List<InstanceRecommendationOption>? recommendationOptions, List<RecommendationSource>? recommendationSources, List<UtilizationMetric>? utilizationMetrics})
InstanceRecommendation.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The AWS account ID of the instance.
final
currentInstanceType → String?
The instance type of the current instance.
final
finding → Finding?
The finding classification for the instance.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceArn → String?
The Amazon Resource Name (ARN) of the current instance.
final
instanceName → String?
The name of the current instance.
final
lastRefreshTimestamp → DateTime?
The time stamp of when the instance recommendation was last refreshed.
final
lookBackPeriodInDays → double?
The number of days for which utilization metrics were analyzed for the instance.
final
recommendationOptions → List<InstanceRecommendationOption>?
An array of objects that describe the recommendation options for the instance.
final
recommendationSources → List<RecommendationSource>?
An array of objects that describe the source resource of the recommendation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utilizationMetrics → List<UtilizationMetric>?
An array of objects that describe the utilization metrics of the instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited