InstanceRecommendationOption class

Describes a recommendation option for an Amazon EC2 instance.

Constructors

InstanceRecommendationOption({String? instanceType, double? performanceRisk, List<UtilizationMetric>? projectedUtilizationMetrics, int? rank})
InstanceRecommendationOption.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceType → String?
The instance type of the instance recommendation.
final
performanceRisk → double?
The performance risk of the instance recommendation option.
final
projectedUtilizationMetrics → List<UtilizationMetric>?
An array of objects that describe the projected utilization metrics of the instance recommendation option.
final
rank → int?
The rank of the instance recommendation option.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited