JobFilter class

Describes a filter that returns a more specific list of recommendation export jobs.

This filter is used with the DescribeRecommendationExportJobs action.

Constructors

JobFilter({JobFilterName? name, List<String>? values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → JobFilterName?
The name of the filter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>?
The value of the filter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited