LambdaFunctionMemoryProjectedMetric class

Describes a projected utilization metric of an AWS Lambda function recommendation option.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → LambdaFunctionMemoryMetricName?
The name of the projected utilization metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistic → LambdaFunctionMemoryMetricStatistic?
The statistic of the projected utilization metric.
final
value → double?
The values of the projected utilization metrics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited