LambdaFunctionMemoryRecommendationOption class

Describes a recommendation option for an AWS Lambda function.

Constructors

LambdaFunctionMemoryRecommendationOption({int? memorySize, List<LambdaFunctionMemoryProjectedMetric>? projectedUtilizationMetrics, int? rank})
LambdaFunctionMemoryRecommendationOption.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
memorySize → int?
The memory size, in MB, of the function recommendation option.
final
projectedUtilizationMetrics → List<LambdaFunctionMemoryProjectedMetric>?
An array of objects that describe the projected utilization metrics of the function recommendation option.
final
rank → int?
The rank of the function recommendation option.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited