LambdaFunctionUtilizationMetric class

Describes a utilization metric of an AWS Lambda function.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → LambdaFunctionMetricName?
The name of the utilization metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistic → LambdaFunctionMetricStatistic?
The statistic of the utilization metric.
final
value → double?
The value of the utilization metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited