ReasonCodeSummary class

A summary of a finding reason code.

Constructors

ReasonCodeSummary({FindingReasonCode? name, double? value})
ReasonCodeSummary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → FindingReasonCode?
The name of the finding reason code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double?
The value of the finding reason code summary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited