RecommendationSource class

Describes the source of a recommendation, such as an Amazon EC2 instance or Auto Scaling group.

Constructors

RecommendationSource({String? recommendationSourceArn, RecommendationSourceType? recommendationSourceType})
RecommendationSource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recommendationSourceArn → String?
The Amazon Resource Name (ARN) of the recommendation source.
final
recommendationSourceType → RecommendationSourceType?
The resource type of the recommendation source.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited