S3Destination class

Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and object keys of a recommendations export file, and its associated metadata file.

Constructors

S3Destination({String? bucket, String? key, String? metadataKey})
S3Destination.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String?
The name of the Amazon S3 bucket used as the destination of an export file.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
The Amazon S3 bucket key of an export file.
final
metadataKey → String?
The Amazon S3 bucket key of a metadata file.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited