UtilizationMetric class

Describes a utilization metric of a resource, such as an Amazon EC2 instance.

Compare the utilization metric data of your resource against its projected utilization metric data to determine the performance difference between your current resource and the recommended option.

Constructors

UtilizationMetric({MetricName? name, MetricStatistic? statistic, double? value})
UtilizationMetric.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → MetricName?
The name of the utilization metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistic → MetricStatistic?
The statistic of the utilization metric.
final
value → double?
The value of the utilization metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited