VolumeConfiguration class

Describes the configuration of an Amazon Elastic Block Store (Amazon EBS) volume.

Constructors

VolumeConfiguration({int? volumeBaselineIOPS, int? volumeBaselineThroughput, int? volumeBurstIOPS, int? volumeBurstThroughput, int? volumeSize, String? volumeType})
VolumeConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeBaselineIOPS → int?
The baseline IOPS of the volume.
final
volumeBaselineThroughput → int?
The baseline throughput of the volume.
final
volumeBurstIOPS → int?
The burst IOPS of the volume.
final
volumeBurstThroughput → int?
The burst throughput of the volume.
final
volumeSize → int?
The size of the volume, in GiB.
final
volumeType → String?
The volume type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited